@@ -69,17 +69,23 @@ class _GStreamerRenderer(BaseRenderer):
 
     @staticmethod
     def GetProperties():
-        return ["Bitrate", "RenderSubtitle"]
+        return ["Bitrate", "RenderSubtitle", "SubtitleSettings"]
 
     @staticmethod
     def GetDefaultProperty(prop):
         if prop == "RenderSubtitle":
             return "false"
+        if prop == "SubtitleSettings":
+            return ""
         return BaseRenderer.GetDefaultProperty(prop)
 
     def ToSink(self, data):
         self.resQueue.put(data)
 
+    def GetOutputFile(self):
+        outFile = '{0}.{1}'.format(self._outFile, self._GetExtension())
+        return outFile
+
     def __CleanUp(self):
         '''
         Waits until the ready event is set and finished the GTK-Mainloop.
@@ -110,7 +116,7 @@ class _GStreamerRenderer(BaseRenderer):
 
         if self.GetTypedProperty("RenderSubtitle", bool):
             # delete subtitle file, if subtitle is rendered in video
-            srtPath = os.path.join(self.GetOutputPath(), "output.srt")
+            srtPath = self._outFile + ".srt"
             if os.path.exists(srtPath):
                 os.remove(srtPath)
 
@@ -140,9 +146,6 @@ class _GStreamerRenderer(BaseRenderer):
         self.imgDuration = int(round(1000 * Gst.MSECOND / frameRate.AsFloat()))
         self._Log(logging.DEBUG, "set imgDuration=%s", self.imgDuration)
 
-        outFile = os.path.join(self.GetOutputPath(),
-                               "output.%s" % self._GetExtension())
-
         self.pipeline = Gst.Pipeline()
 
         caps = Gst.caps_from_string(
@@ -168,6 +171,7 @@ class _GStreamerRenderer(BaseRenderer):
         if self.GetTypedProperty("RenderSubtitle", bool) and Gst.ElementFactory.find("textoverlay"):
             self.textoverlay = Gst.ElementFactory.make("textoverlay")
             self.textoverlay.set_property("text", "")
+            self._SetupTextOverlay()
             self.pipeline.add(self.textoverlay)
 
         # link elements for video stream
@@ -231,7 +235,11 @@ class _GStreamerRenderer(BaseRenderer):
         videoQueue2 = Gst.ElementFactory.make("queue")
         self.pipeline.add(videoQueue2)
 
-        videoEnc.link(videoQueue2)
+        videoEncCaps = self._GetVideoEncoderCaps()
+        if videoEncCaps:
+            videoEnc.link_filtered(videoQueue2, videoEncCaps)
+        else:
+            videoEnc.link(videoQueue2)
         videoQueue2.link(mux)
 
         if audioEnc:
@@ -241,7 +249,7 @@ class _GStreamerRenderer(BaseRenderer):
             audioQueue2.link(mux)
 
         sink = Gst.ElementFactory.make("filesink")
-        sink.set_property("location", outFile)
+        sink.set_property("location", self.GetOutputFile())
         self.pipeline.add(sink)
 
         mux.link(sink)
@@ -362,7 +370,7 @@ class _GStreamerRenderer(BaseRenderer):
         if self.textoverlay:
 #             self.textoverlay.set_property("text", "Frame: %s" % self.idxFrame)
             if self.srtParse is None:
-                srtPath = os.path.join(self.GetOutputPath(), "output.srt")
+                srtPath = self._outFile + ".srt"
                 self.srtParse = SrtParser(
                     srtPath, self.GetProfile().GetFrameRate().AsFloat())
 
@@ -413,6 +421,23 @@ class _GStreamerRenderer(BaseRenderer):
         else:
             return Gst.PadProbeReturn.PASS
 
+    def _SetupTextOverlay(self):
+        settings = self.GetProperty("SubtitleSettings")
+        for singleSetting in settings.split(";"):
+            settingAndProp = singleSetting.split("=")
+            if len(settingAndProp) == 2:
+                prop, value = settingAndProp
+                try:
+                    # try number as int
+                    value = int(value)
+                except:  # pylint: disable-msg=bare-except
+                    try:
+                        # try numbers as hex
+                        value = int(value, 16)
+                    except:  # pylint: disable-msg=bare-except
+                        pass
+                self.textoverlay.set_property(prop, value)
+
     def _GetExtension(self):
         raise NotImplementedError()
 
@@ -425,6 +450,9 @@ class _GStreamerRenderer(BaseRenderer):
     def _GetVideoEncoder(self):
         raise NotImplementedError()
 
+    def _GetVideoEncoderCaps(self):
+        return None
+
 
 class MkvX264AC3(_GStreamerRenderer):
 
@@ -448,9 +476,19 @@ class MkvX264AC3(_GStreamerRenderer):
             if mux is None:
                 msgList.append(_(u"MKV-Muxer (gstreamer1.0-plugins-good) required!"))
 
+    @staticmethod
+    def GetDefaultProperty(prop):
+        if prop == "Profile":
+            return "high"
+        elif prop == "HardwareEncoding":
+            return "false"
+        else:
+            return _GStreamerRenderer.GetDefaultProperty(prop)
+
     @staticmethod
     def GetProperties():
-        return _GStreamerRenderer.GetProperties() + ["SpeedPreset"]
+        return _GStreamerRenderer.GetProperties() + [
+            "SpeedPreset", "Profile", "HardwareEncoding"]
 
     def _GetExtension(self):
         return "mkv"
@@ -469,7 +507,10 @@ class MkvX264AC3(_GStreamerRenderer):
         return audioEnc
 
     def _GetVideoEncoder(self):
-        videoEnc = Gst.ElementFactory.make("x264enc")
+        if self.GetTypedProperty("HardwareEncoding", bool) and Gst.ElementFactory.find("vaapih264enc"):
+            videoEnc = Gst.ElementFactory.make("vaapih264enc")
+        else:
+            videoEnc = Gst.ElementFactory.make("x264enc")
         videoEnc.set_property("bitrate", self._GetBitrate())
 
         speedPreset = self.GetTypedProperty("SpeedPreset", int)
@@ -477,6 +518,17 @@ class MkvX264AC3(_GStreamerRenderer):
             videoEnc.set_property("speed-preset", speedPreset)
         return videoEnc
 
+    def _GetVideoEncoderCaps(self):
+        profile = self.GetTypedProperty("Profile", str)
+        if profile in ("main", "high", "baseline", "constrained-baseline"):
+            caps = Gst.caps_from_string("video/x-h264,profile={}".format(profile))
+            return caps
+        elif profile:
+            self._Log(logging.WARN,
+                      "value '%s' for profile not supported!",
+                      profile)
+        return None
+
 
 class Mp4X264AAC(_GStreamerRenderer):
 
@@ -500,9 +552,19 @@ class Mp4X264AAC(_GStreamerRenderer):
             if mux is None:
                 msgList.append(_(u"FLV-Muxer (gstreamer1.0-plugins-good) required!"))
 
+    @staticmethod
+    def GetDefaultProperty(prop):
+        if prop == "Profile":
+            return "high"
+        elif prop == "HardwareEncoding":
+            return "false"
+        else:
+            return _GStreamerRenderer.GetDefaultProperty(prop)
+
     @staticmethod
     def GetProperties():
-        return _GStreamerRenderer.GetProperties() + ["SpeedPreset"]
+        return _GStreamerRenderer.GetProperties() + [
+            "SpeedPreset", "Profile", "HardwareEncoding"]
 
     def _GetExtension(self):
         return "mp4"
@@ -516,13 +578,27 @@ class Mp4X264AAC(_GStreamerRenderer):
         return audioEnc
 
     def _GetVideoEncoder(self):
-        videoEnc = Gst.ElementFactory.make("x264enc")
+        if self.GetTypedProperty("HardwareEncoding", bool) and Gst.ElementFactory.find("vaapih264enc"):
+            videoEnc = Gst.ElementFactory.make("vaapih264enc")
+        else:
+            videoEnc = Gst.ElementFactory.make("x264enc")
         videoEnc.set_property("bitrate", self._GetBitrate())
         speedPreset = self.GetTypedProperty("SpeedPreset", int)
         if speedPreset is not None:
             videoEnc.set_property("speed-preset", speedPreset)
         return videoEnc
 
+    def _GetVideoEncoderCaps(self):
+        profile = self.GetTypedProperty("Profile", str)
+        if profile in ("main", "high", "baseline", "constrained-baseline"):
+            caps = Gst.caps_from_string("video/x-h264,profile={}".format(profile))
+            return caps
+        elif profile:
+            self._Log(logging.WARN,
+                      "value '%s' for profile not supported!",
+                      profile)
+        return None
+
 
 class MkvX265AC3(_GStreamerRenderer):
 
